.TH \fBGraphEnt n \fR
.SH Name
GraphEnt, Version Beta, Release 1.1
.SH Syntax
.B GraphEnt [<ascii file name>]

.B GraphEnt [zone] [<low_res> <high_res>] <CCP4 mtz file>
where {zone} = {H00,0K0,00L,HH0,-HH0,HHH,HK0,0KL,H0L,HHL}

.SH Description

\fIGraphEnt\fR is an attempt to provide an automatic way for calculating the maximum entropy map
that corresponds to a set of observations, while offering a useful graphical output of
the current stage of the calculations.

Although the automation is mainly directed towards
the macromolecular crystallographic community (with direct support for CCP4 mtz reflection
files), it is also quite straightforward for the general crystallographic community
to use the program.

.SH Usage.

This manual page only contains a description of the various keywords that are
recognised by GraphEnt in the script mode, and is supposed to aid writing and editing such scripts.
For a complete description of the automatic modes and other program details, please
refer to the postscript documentation included with the program distribution.

.SH An example script.

.nf
# 
# 
# Automatically produced by GraphEnt
# 
# 

#
# Cell and space group number
#
CELL        \N'57'4.3\N'57'5 24.253 64.537 \N'57'0.0 130.42\N'57' \N'57'0.0
SPACEGROUP  1

#
# Output map format
#
MAP_FORMAT        CCP4

#
# Difference Patterson calculation assumed. 
# Exclude small differences.
#
DIFF_PATT
LIMIT             0.50

#
# Axes permutation and grid spacing.
#
PERMUTATION       3 1 2
GRID              112    160     40

#
# Graphics support and options.
#
PSOUT
GRACYCLES       2
GRATWOWINDOWS

#
# Reflection records follow
#
REFLECTIONS
  -24   0   5   17\N'57'.857\N'57'6  2.\N'57'28\N'57'6  164.14645  55.75112
  -23  -3   7   275.83127  3.02327  334.24408  25.4\N'57'015
  .....................................................
.fi

The characters #, ! and *, when they occur at the beginning of a line
inform GraphEnt to ignore the rest of the line. A complete list of keywords understood by the
program follows.

.SH Cell and symmetry related keywords

.SS CELL a b c alpha beta gamma

This keyword defines the unit cell dimensions. Six floating point numbers are expected.

.SS GRID nfast nmedium nslow

This keyword sets the number of (integer)
divisions along the whole unit cell edges for the 
fast, medium and slow axes. Which axis is fast, medium and slow is determined by the
\fBPERMutation\fR keyword. To keep the FFT as fast as possible, GraphEnt will only cooperate
if the grid sizes are any of the following :
.nf
       1,       2,       4,       6,       8,      10,
      12,      14,      16,      20,      24,      28,
      30,      32,      40,      42,      48,      56,
      60,      64,      70,      80,      84,      \N'57'6,
     112,     120,     128,     140,     160,     168,
     1\N'57'2,     210,     224,     240,     256,     280,
     320,     336,     384,     420,     448,     480,
     512,     560,     640,     672,     768,     840,
     8\N'57'6,     \N'57'60,    1024
.fi
If you need more than 1024 grid points on any axis, then you are better off finding a
program encoding for a  more efficient maximum entropy 
algorithm (because with GraphEnt you will probably never finish the calculation).

.SS PERMutation fastID mediumID slowID

This keyword defines the axes permutations, ie which axis is the fastest 
changing, the medium, 
and the sectioning. The various axes are identified with the following convention: 
\fIx\fR is 1, \fIy\fR is 2, \fIz\fR is 3. For example, to define a valid permutation for a monoclinic space group
with b unique, you give \fBPERM 3 1 2\fR. In this case the first argument of
GRID should be the number of divisions of the \fIc\fR axis, followed by the number of
divisions along \fIa\fR and, finally, \fIb\fR. 

NOTE WELL : Changing the axes permutation without
careful thinking is a standard way to inverse the chirality of your molecule. GraphEnt will 
\fBnot\fR stop you from changing enantiomorph.

.SS F000 f

This keyword sets the value for the F000 term. Although GraphEnt will chose a value by
default, more often than not this will not be ideal. The importance of this term for
the calculation is discussed analytically in the documentation and will not be
repeated here. I will just mention that a completely wrong value for the F000 term is 
the most common source of problems with the program.

.SS SPACegroup n

Where \fBn\fR is the spacegroup number of your crystals. Since GraphEnt is doing the 
calculation in \fIP1\fR, what you give here is absolutely irrelevant with respect to the 
actual calculation performed. It is only used to have a correctly formed map header
in the case of the CCP4-related map files.

.SH Graphics-related keywords

.SS GRACycles n

The maxent plot will be updated every \fBn\fR iterations. Only applicable if your executable 
was compiled with graphics support.

.SS GRAGrayscale

The density will ploted using a combination of grayscale representation and contouring.
Nice if you are looking at protein maps at low resolution. Confusing for `peaky' maps.
Only applicable if your executable 
was compiled with graphics support.

.SS GRATwowindows

This tells PGPLOT to open a new window in which to plot the maxent map, while keeping the
window containing the conventional map (thus allowing you to compare the maps as you go
along the calculation). I can see no reason for not having two (or more) windows.
Only applicable if your executable 
was compiled with graphics support.

.SS GRAWait

If this keyword is specified, GraphEnt will prompt you to press <ENTER> every time that the
maxent map must be updated. I bet you will be bored pressing <ENTER> quite soon.
Only applicable if your executable 
was compiled with graphics support.

.SS GRASection f

This keyword allows you to specify which section GraphEnt should plot during the calculation. 
The value defined is the fractional coordinate (along the sectioning axis, see keyword \fBPERM\fR) 
of the required section. The default is the zero level section.
Only applicable if your executable was compiled with graphics support.

.SS GRANsections n

This keyword allows you to plot not just one section, but a stack of
successive sections, where \fBn\fR is the number of sections to stack.
Note that the program does not plot successive sections one on top of the 
other : instead, for every grid point it will find the maximum density on
any of the defined sections, and will plot the resulting (maximum density)
map. Only applicable if your executable 
was compiled with graphics support.


.SS GRAFirst f

This keyword specifies the density level for plotting the first (dotted) contour line.
This contour will be plotted at  \fIrho\fR + \fBf\fR * \fIsigma(rho)\fR, where 
\fIrho\fR is the mean density of the section that is being plotted, and 
\fIsigma(rho)\fR the corresponding rms deviation (again, not of the whole map but only
of given section). To the best of my knowledge, GraphEnt will allow you to give \fBf\fR a negative
value, thus allowing you to start contouring from below the mean density level (although I
bet that you could crash either GraphEnt or PGPLOT by giving random values to this 
parameter). Default is 0.0 (ie, first contour at the mean density).

.SS GRALevel f

This keyword defines the interval (in terms of number of rms deviations) for plotting the 
contours in the two graphics windows. Following the first contour (defined by 
the GRAFirst keyword), contours will be plotted every \fBf\fR times the 
rms deviation of the given map section. Default is 0.5 (ie, plot every 0.5 rmsd).

.SS GRAMaxContours n

This keyword defines the maximum number of contour lines that can be drawn
in the graphics windows. The intension is to reduce the workload on the X
server when a Patterson function is plotted and the rms deviation of the
current map section is so small that several hundred (or even thousand)
contour lines must be drawn for the origin peak.

.SS VT125

This keyword switches-on PGPLOT's support for ReGIS graphics, making it possible
to see GraphEnt's graphics from a whole series of ReGIS-capable VT terminals (eg VT125,
VT240, VT241, VT330, VT330+, VT340, ...). To make things go faster
(especially if you are calculating a Patterson function), consider adding
a \fBGRAMaxContours\fR keyword, and increasing the value of \fBGRACycles\fR.
You may also want to define the \fBGRAWait\fR keyword. Enjoy (and don't let
anyone touch your VTs).

.SS ONEDimensional u v u0 v0

This keyword allows you do make 1D x-y plots (instead of 2D contour plots)
of the distribution of density along a specified line of the \fIcurrent\fR
section (ie plotting the distribution of density along an arbitrary
direction in 3D is not supported. The line must belong to the current map
section). The first two parameters define the direction of the axis \fB[uv]\fR
whose density is to be plotted, where \fBu\fR is measured along the
fast-changing axis of the current section, and \fBv\fR along the medium axis
(see keyword \fBPERM\fR). The two additional parameters
define the starting point (origin) for the 1D graph in the two-dimensional
section (usually 0.0). \fBu0\fR and \fBv0\fR should be given in fractional coordinates
(in the crystallographic frame) along the fast- and medium-changing axes.
When 1D data are given on input (in the form of h00, 0k0 or 00l data),
GraphEnt will automatically make the decisions for you.

If for example, you want to make a 1D plot of the distribution of density on
a line parallel to the [31] direction and passing from the origin, you can
use \fBONED 3 1 0 0\fR.

When 1D data are plotted, the program will draw a horizontal dotted line at
the mean density, and a series of tick marks at
\fIn*sigma(rho)\fR where \fIsigma(rho)\fR is the rms deviation of the 1D
data. Please also note that the program will take values (from the
underlying 2D section) at regularly spaced intervals using a simple 4-point
linear interpolation.

.SH Reflection selection and modification.

.SS REJEct

When this keyword is present, GraphEnt will attempt to open a file named \fBREJECT.HKL\fR 
(case in important) from the current directory, which contains in its first three
columns the indeces of reflections that should be excluded from the calculation. The following
is a valid \fBREJECT.HKL\fR file :
.nf
   0   0   6    -2.\N'57'\N'57'385       -30.6\N'57'588
   2   0   4    -2.64107       -28.07780
 -12   0   8      
   0   0  11     Everything after the first three numbers
  -4   0   8     on a line of input is ignored
.fi

.SS EXCLude_diff f

When calculating a difference Patterson function, reflections for which the 
magnitude of the observed difference is  larger than \fBf\fR will be excluded from the 
calculation.

.SS EXFOm f

Reflections with a figure-of-merit less than \fBf\fR will be excluded from the calculation (treated
as if unobserved). This is yet another of the unsuccessful ad hockeries tried for improving 
FOM-weighted phased syntheses (see the documentation for details).

.SS SQRT_sigmas f

For testing purposes only : the standard deviations are set to sigma(F)=\fBf\fR*sqrt(F). 

.SS AVERage_sigma f

For testing purposes only : the standard deviations are set to sigma(F)=\fBf\fR. 

.SS KFOM

For testing purposes only : the input FOMs will be multiplied by \fBf\fR.

.SS MAXFom f

For testing purposes only : all input FOMs greater than \fBf\fR, are set to \fBf\fR.

.SS MINFom f

For testing purposes only : all input FOMs less than \fBf\fR, are set to \fBf\fR.

.SS LIMIt f

This keyword instructs GraphEnt to exclude all reflections with \fIF/sigma(F)\fR < \fBf\fR from the 
calculation. The exclusion takes place after all processing of the data is finished 
(ie, taking differences, squaring, etc). It would appear that the presence of this
keyword defeats the purpose of GraphEnt. This is correct with one exception : When calculating
a 3D isomorphous difference Patterson function, and because the phases of \fBF_h\fR and 
\fBF_p\fR are not correlated, a small value for \fB(F_ph - F_p)\fR (for acentric reflections)
will only contain valid information about \fBF_h\fR for only half of the cases. Excluding
small differences from this type of calculation is not as harmful as it would be in other cases. My
experience is that giving a \fBLIMIt 1.0\fR gives almost identical difference Patterson
functions, but in a fraction of the time that the proper (no exclusions) run would take. In some
cases adding this keyword makes the difference between achieving convergence and 
wasting CPU time.

.SS SCALe f

When this keyword is present, the data (amplitude and its standard deviation) will be
multiplied by the given constant \fBf\fR. The multiplication takes place after all 
processing of the data is finished (ie, taking differences, squaring, etc). Downscaling
the data may be useful when the (extreme) 
sharpness of the MaxEnt map suggests that the data
may be way off the absolute scale (on the high side, ie they must be downscaled). 
I think that
rescaling the data at this stage is totaly unjustified. The only good excuse that
I can think of, is in the case of an isomorphous difference Patterson 
function calculation : if the derivative
is non-isomorphous (assuming that an isomorphous derivative ever existed), then
there are good chances that with increasing resolution, the mean fractional isomorphous
difference will increase (instead of  decreasing). This could fool maxent into believing
that there are good-strong data even at high resolution. 
This, of course is correct, the only
problem being that
these ``strong'' high resolution data is noise from our point of view (these large
differences arise from the non-isomorphism and not from the heavy atom structure). 

.SH Calculus and limits-related keywords.

.SS TARGet f

This keyword defines the value of the \fIchi^2\fR at which the calculation will stop. Normally
this is equal to the number of observations. If you want to stop earlier (a more uniform map),
or later (a more peaky map), you can achieve this either by changing the \fBTARGet\fR, or 
changing the standard deviations of your measurements. I should warn you, however, that both
procedures are probably wrong (and dangerous), unless you have reasons to believe that
the standard deviations of your measurements are incorrect.

.SS PHASeless f

When this keyword is present and the calculation performed is a FOM-weighted synthesis,
then all reflections with a figure of merit less than \fBf\fR will enter the calculation 
with only amplitude restraints, but no phase restraints. The idea behind it, is that due
to the algorithm used by GraphEnt, reflections with
a high F/sigma(F) but low FOM, will effectively be treated as weak. By removing the
phase restraints, strong reflections (but with largely unknown phase) will be treated 
as strong reflections with unknown phase. The hope is that their phases will converge
to a value that maximises the configurational entropy of the map (while being consistent
with their amplitudes). Now, this whole thing (of arbitrarily selecting a FOM cutoff 
to switch-off phase restraints) is clearly an \fIad hockery\fR which is neither
promising, nor convincing (but you can give it a try just in case). This is more
extensively discussed in the documentation. I should add (just to avoid any
misunderstandings), that the iteration is started using the phase angles given to the program 
(ie. it is not a random-phase seeded calculation), and that the FOMs given are not
ignored but are used to adjust how fast the corresponding amplitudes will approach
convergence.

.SS SWITch f

This is yet another \fIad hockery\fR closely related to the \fBPHASeless\fR keyword
described above. The idea in this case, is to start the calculation of a
FOM-weighted synthesis in the usual way, but when the R-factor reaches the value
\fBf\fR, to switch to a \fBPHASeless\fR calculation for all reflections in the data
set.

.SS LAMBda f

This sets the initial value of the Lagrange multiplier for the calculation to \fBf\fR. 
If this 
keyword is \fBnot\fR given, GraphEnt will determine a suitable starting value for it by 
performing a limited number of iterations at different starting \fIlambda\fR values. 
Better leave it to the automatic mode.

.SS CONStant_lambda

The normal way to perform the calculation is to gradually increase the value of the
Lagrange multiplier \fIlambda\fR till the iteration starts diverging. Then the program switches
to a constant \fIlambda\fR mode, during which the value of the multiplier can only be decreased
(again when the iteration diverges). If you define the keyword \fBCONST\fR, then GraphEnt
will start directly from the constant \fIlambda\fR mode.

.SS REMOve_origin_peak

This keyword is intended for calculation of origin-removed Patterson functions. This is
achieved by subtracting the average \fIF^2\fR from all contributing observations. 
\fBDo not use this keyword\fR : the correct way to do the calculation is to subtract the local (in thin 
resolution shells) average of the observations (and not the global average). If you want
an origin-removed Patterson function and you have CCP4 installed, use the program 
\fBecalc\fR to calculate the coefficients.

.SS CHILimit f

All reflections that contribute to the final value of \fIchi^2\fR by more than \fBf\fR times
the rmsd contribution of all reflections, will be written to the file
\fBCHIcontributions.dat\fR. Outstandingly large contributions to \fIchi^2\fR may indicate
a problem with the measurement, or a significant underestimation of its standard deviation.
The default is 10.

.SH Miscellaneous keywords.

.SS VERBose

If this keyword is given, GraphEnt will be writing out quite a lot of info. 
From release 0.3 onwards, this is \fBno\fR \fBlonger\fR the default.

.SS TIME n

\fBn\fR is the maximum number of minutes that GraphEnt may use for the calculation. When the time
limit is reached, GraphEnt will write out the current map and die peacefully. Please note that
the time is given in minutes and is absolute, ie it is the actual time passed since the
calculation started, and not the CPU time consumed by GraphEnt. 
When this keyword is not present, GraphEnt will just keep on going (hopefully not for ever).

.SS PSOUt

When this keyword is present (and if the program was compiled with graphics support), two
postscript files will be produced containing a plot of the contents of the two graphics
windows (conventional and GraphEnt map). The section that will be plotted is the same as the
one selected with the \fBGRASection\fR keyword.

.SS TRANsforms

USEFUL ONLY FOR CREATING COVER PICTURES :
When this keyword is specified, GraphEnt will produce two additional ASCII files, with the
names MAXENT_TRANS.dat and START_TRANS.dat. These files contain information
about the coordinates (in reciprocal Angstroem) and 
amplitudes of the reflections lying on the first section of the reciprocal lattice,
both before and after the calculation. The first section of the reciprocal lattice before
the calculation is simply a section of 
the input data (without phase and FOM information). The 
same section after the calculation corresponds to a section from the modulus of the
Fourier transform of the GraphEnt map. An example of using these files for preparing a plot,
was the cover image of a long-forgotten version of the postscript documentation.

.SS SHOW

If this keyword is given, GraphEnt will be writing out
an additional column containing the value of the entropy of the current map. 

.SH Mode selection and output formats.

.SS MAP_format ASCII | CCP4 | NA4

This keyword determines the map format that GraphEnt will use. These are discussed
extensively in the postscript document.

.SS PATTerson

When this keyword is present, GraphEnt expects to read 5 (and only 5) columns for each
reflection record, which will be interpreted as \fBh, k, l, |F|, sigma(|F|)\fR for a Patterson
function calculation. The data will
be squared, the standard deviations corrected accordingly and the phases set to zero
before the calculation is started.

.SS DIFF_patterson

When this keyword is present, GraphEnt expects to read 7 (and only 7) columns for each
reflection record, which will be interpreted as 
\fBh, k, l, |F1|, sigma(|F1|), |F2|, sigma(|F2|)\fR for a difference Patterson calculation. 
The difference and its standard deviation will be calculated, the resulting data
will be squared and the phases set to zero before the calculation is started.

.SS FOM

When this keyword is present, GraphEnt expects to read 7 (and only 7) columns for each
reflection record, which will be interpreted as 
\fBh, k, l, |F|, sigma(|F|), phi, FOM\fR for a \fIm|F|exp(iPhi)\fR synthesis.
For this type of calculation some additional approximations are performed, which are 
discussed in the postscript documentation.

.SS REFLections

This must be the last keyword before the reflection records begin. 

.SH Comments, suggestions and bug reports.
Please send comments, suggestions and bug reports to 
\fIglykos@crystal2.imbb.forth.gr\fR or \fIglykos@imbb.forth.gr\fR.

.SH Latest version
You can get the latest release of the program via
\fBhttp://origin.imbb.forth.gr/~glykos/\fR
